@@ -2,7 +2,7 @@ __title__ = 'tkt-Toolkit'
 __author__ = 'Suprime'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020-2021 Suprime'
-__version__ = '1.5.2'
+__version__ = '1.5.4'
 
 __tkt_OUS_ex__ = True
 __ext_TTA__ = False
@@ -15,7 +15,7 @@ class TikTok:
     """
     Uses functionalities from the TikTokApi
     package and makes them more user friendly.
-    Does only work if you set __ext_TTA__ = False
+    Does only work if you set __ext_TTA__ = True
     """
     Music = Script_2.music
     User = Script_1.userData
@@ -45,17 +45,20 @@ class Info:
 class Toolkit:
     class Crypto:
         """
-        Uses the cryptography package to
-        encrypt/decrypt 'Text' with 'Key'
-        !! Does not work !!
+        Uses the cryptography package and xor to
+        encrypt/decrypt 'Text'. Encrypt return a tuple
         """
-        def encrypt(Text:str,Key:str):
-            raise OutOfService
-            return Crypto.using.encrypt(Text.encode(),Key.encode())
-        def decrypt(Text:str,Key:str):
-            raise OutOfService
-            return Crypto.using.decrypt(Text.encode(),Key.encode())
-
+        def encrypt(Text:bytes):
+            return Crypto.crypto.encrypt(Text)
+        def decrypt(Text:bytes,Key:bytes):
+            return Crypto.crypto.decrypt(Key,Text)
+    def del_all(dir : str,log:bool=True):
+        """
+        Clears the folders and then deletes
+        them, using os.listdir,os.remove,os.rmdir
+        """
+        parse.using.del_files(dir,log)
+        parse.using.del_folders(dir,log)
     def getip(S=""):
         """
         Gets the users IP using the python
@@ -75,7 +78,6 @@ class Toolkit:
         the language.
         """
         return translator.Translate(Text,Dest,From)
-
     def weather(city:str, key:str):
         """
         Gets the weather from openweathermap.org,
